Array API Standard Support: ``stats.qmc``
=========================================

.. _array_api_support_stats_qmc_cpu:

Support on CPU
--------------

.. array-api-support-per-function::
    :module: stats.qmc
    :backend_type: cpu

.. _array_api_support_stats_qmc_gpu:

Support on GPU
--------------

.. array-api-support-per-function::
    :module: stats.qmc
    :backend_type: gpu

.. _array_api_support_stats_qmc_jit:

Support with JIT
----------------

.. array-api-support-per-function::
    :module: stats.qmc
    :backend_type: jit
